# History

v1.5.5 (2022-08-19)

- Improved Qt5 QML example template.
- Added Qt5 console example template
- Create a note source example at the same time as the note is created.

v1.5.4 (2022-08-15)

- Fixed
    - timeout issue when unzipping a file
- Added
    - example project scaffold

v1.5.3 (2022-08-15)

- Added
    - golang web example templates
    - cpp Qt5 example templates
- Updated
    - ansible templates

v1.5.2 (2022-08-13)

- Improved Qt5 template.
- Improved Python example template.

v1.5.1 (2022-08-12)

- Added
    - more templates
    - improved ansible templates
- Fixed
    - KeyError when deleting `factory` field
    - package typo in Go templates
    - unzip timeout

v1.5.0 (2022-08-10)

- Added
    - generate files from templates for existing project

v1.4.5 (2022-08-09)

- Added
    - use multiple templates at the same time
    - ansible project scaffold
    - golang example and cli project scaffold

v1.4.4 (2022-08-09)

- Fixed
    - missing `python_user_input_context_hook`
    - bad LICENSE reference
- Added
    - serialization module for configuration
    - `enable_click_group` option for python template
